@@ -50,10 +50,11 @@ namespace mamba
         void add_pins(const std::vector<std::string>& pins);
         void set_flags(const std::vector<std::pair<int, int>>& flags);
         void set_postsolve_flags(const std::vector<std::pair<int, int>>& flags);
-        bool is_solved();
+        bool is_solved() const;
         bool solve();
-        std::string problems_to_str();
-        std::string all_problems_to_str();
+        std::string problems_to_str() const;
+        std::vector<std::string> all_problems() const;
+        std::string all_problems_to_str() const;
 
         const std::vector<MatchSpec>& install_specs() const;
         const std::vector<MatchSpec>& remove_specs() const;
